@@ -10,6 +10,7 @@ import requests
 import hashlib
 import envx
 import json
+import urllib3
 
 
 def make_sk(
@@ -75,7 +76,8 @@ def make_signer(
 def make_sign_request(
         ak: str,
         sk: str,
-        data: dict
+        data: dict,
+        verify: bool = True
 ):
     """
     自动签名并发起请求
@@ -86,7 +88,8 @@ def make_sign_request(
         method: 必填，请求方法：GET/POST
         url: 必填，请求的url，例如 https://...
         query: 必填，请求要发送的数据，为json格式
-    如果data数据中包含sk、sign，在签名时会自动剔除
+        如果data数据中包含sk、sign，在签名时会自动剔除
+    :param verify: 是否验证ssl证书
 
     正确返回：{'code': 0, 'msg': 'success', 'data': '...'}
     """
@@ -97,11 +100,20 @@ def make_sign_request(
     )
     if sign_res['code'] == 0:
         data['sign'] = sign_res['data']
-        response = requests.request(
-            method=data['method'],
-            url=data['url'],
-            json=data
-        )
+        if verify is False:
+            urllib3.disable_warnings()
+            response = requests.request(
+                method=data['method'],
+                url=data['url'],
+                json=data,
+                verify=False
+            )
+        else:
+            response = requests.request(
+                method=data['method'],
+                url=data['url'],
+                json=data
+            )
         return response.json()
     else:
         return sign_res
